##  Difference Between a Production and a Sandbox Workspace
A production workspace is the main SAP LeanIX environment where an organization stores and manages its real enterprise architecture data using a standard, predefined, yet configurable meta model.
A sandbox workspace, available through an additional subscription, is a separate environment used for proof-of-concept testing and activities that can have a large-scale impact on live data when applied in the production environment. A sandbox workspace is geared towards the core team, and the number of users who can access it is limited.
A sandbox workspace isn’t meant for user training, onboarding, or as a staging environment for configuration changes with scheduled synchronization of the live inventory data. Not all activities within the workspace, except for changes made to fact sheets, are recorded in the audit trail. Therefore, we do not support manually triggering the transfer of data and configuration changes between workspaces, although you can request to clone the production workspace to the sandbox through [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") or [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/").
